exceptiontools.AssignabilityError
=================================

.. abjad-lineage:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError

.. autoclass:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__unicode__
   :noindex:
